summaryrefslogtreecommitdiff
path: root/cli_args.go
diff options
context:
space:
mode:
authororcas2019-09-15 00:32:54 +0800
committerJakob Unterwurzacher2020-02-28 22:17:59 +0100
commit9ec042f2f62bc95154d6c8b3215a2e7853f8f5c6 (patch)
tree3a2225151361c7f2f51f57b51d613e29d6ce809b /cli_args.go
parenteeefddad6a254607329c08a4ed6051c068283a06 (diff)
Show undecryptable filenames if they match supplied glob
Resolves https://github.com/rfjakob/gocryptfs/issues/393
Diffstat (limited to 'cli_args.go')
-rw-r--r--cli_args.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/cli_args.go b/cli_args.go
index 0462fb4..a036a2a 100644
--- a/cli_args.go
+++ b/cli_args.go
@@ -32,8 +32,8 @@ type argContainer struct {
dev, nodev, suid, nosuid, exec, noexec, rw, ro bool
masterkey, mountpoint, cipherdir, cpuprofile,
memprofile, ko, passfile, ctlsock, fsname, force_owner, trace string
- // -extpass can be passed multiple times
- extpass multipleStrings
+ // -extpass and -badname can be passed multiple times
+ extpass, badname multipleStrings
// For reverse mode, several ways to specify exclusions. All can be specified multiple times.
exclude, excludeWildcard, excludeFrom multipleStrings
// Configuration file name override
@@ -199,6 +199,7 @@ func parseCliOpts() (args argContainer) {
// -extpass
flagSet.Var(&args.extpass, "extpass", "Use external program for the password prompt")
+ flagSet.Var(&args.badname, "badname", "Glob pattern invalid file names that should be shown")
flagSet.IntVar(&args.notifypid, "notifypid", 0, "Send USR1 to the specified process after "+
"successful mount - used internally for daemonization")